@@ -16,17 +16,18 @@ limitations under the License.
 #ifndef CUDA_CUDA_CONFIG_H_
 #define CUDA_CUDA_CONFIG_H_
 
-#define TF_CUDA_VERSION "11.8"
-#define TF_CUDART_VERSION "11.0"
-#define TF_CUBLAS_VERSION "11"
+#define TF_CUDA_VERSION "12.8.0"
+#define TF_CUDART_VERSION "12"
+#define TF_CUPTI_VERSION "12"
+#define TF_CUBLAS_VERSION "12"
 #define TF_CUSOLVER_VERSION "11"
 #define TF_CURAND_VERSION "10"
-#define TF_CUFFT_VERSION "10"
-#define TF_CUSPARSE_VERSION "11"
-#define TF_CUDNN_VERSION "8"
+#define TF_CUFFT_VERSION "11"
+#define TF_CUSPARSE_VERSION "12"
+#define TF_CUDNN_VERSION "9"
 
-#define TF_CUDA_TOOLKIT_PATH "/opt/cuda"
+#define TF_CUDA_TOOLKIT_PATH ""
 
-#define TF_CUDA_COMPUTE_CAPABILITIES 52, 53, 60, 61, 62, 70, 72, 75, 80, 86, 87, 89, 90, 90
+#define TF_CUDA_COMPUTE_CAPABILITIES 60, 70, 80, 89, 90
 
 #endif  // CUDA_CUDA_CONFIG_H_
